# Gaussian Distribution package

This package consists of the file for Gaussian Distribution calculation based on the file provided

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

You need Python and this is being packaged at pypl

```
 examples
```
